==> totoui-0.3.0.tgz: package/lib/goTop.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var _minxinsSmoothScrollMixin = require('./minxins/SmoothScrollMixin');

var _minxinsSmoothScrollMixin2 = _interopRequireDefault(_minxinsSmoothScrollMixin);

var _utilsEvents = require('./utils/Events');

var _utilsEvents2 = _interopRequireDefault(_utilsEvents);

var _utilsDebounce = require('./utils/debounce');

var _utilsDebounce2 = _interopRequireDefault(_utilsDebounce);

var _utilsDomUtils = require('./utils/domUtils');

var _utilsDomUtils2 = _interopRequireDefault(_utilsDomUtils);

var _utilsCSSCore = require('./utils/CSSCore');

var _utilsCSSCore2 = _interopRequireDefault(_utilsCSSCore);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var GoTop = (function (_React$Component) {
    _inherits(GoTop, _React$Component);

    function GoTop(props) {
        _classCallCheck(this, GoTop);

        _get(Object.getPrototypeOf(GoTop.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
        for (var b in _minxinsSmoothScrollMixin2['default']) {
            this[b] = _minxinsSmoothScrollMixin2['default'][b].bind(this);
        }
        this.isAutoHide = this.isAutoHide.bind(this);
        this.renderIcon = this.renderIcon.bind(this);
        this.handleClick = this.handleClick.bind(this);
    }

    _createClass(GoTop, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            if (this.isAutoHide()) {
                var check = this.checkPosition;

                check();

                this._listener = _utilsEvents2['default'].on(window, 'scroll', (0, _utilsDebounce2['default'])(check, 100));
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this._listener && this._listener.off();
        }
    }, {
        key: 'checkPosition',
        value: function checkPosition() {
            var action = (_utilsDomUtils2['default'].scrollTop(window) > 50 ? 'add' : 'remove') + 'Class';

            _utilsCSSCore2['default'][action](_react2['default'].findDOMNode(this), this.setClassNamespace('active'));
        }
    }, {
        key: 'isAutoHide',
        value: function isAutoHide() {
            return this.props.theme === 'fixed' && this.props.autoHide;
        }
    }, {
        key: 'handleClick',
        value: function handleClick(e) {
            e.preventDefault();
            this.smoothScroll();
        }
    }, {
        key: 'renderIcon',
        value: function renderIcon() {
            return this.props.src ? _react2['default'].createElement('img', {
                className: this.prefixClass('icon-custom'),
                src: this.props.src,
                alt: this.props.title }) : _react2['default'].createElement(_iconJsx2['default'], {
                className: this.prefixClass('icon'),
                icon: this.props.icon || 'chevron-up' });
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();

            classSet[this.prefixClass(this.props.theme)] = true;
            classSet[this.setClassNamespace('active')] = !this.isAutoHide();

            return _react2['default'].createElement(
                'div',
                _extends({}, this.props, {
                    'data-am-widget': this.props.classPrefix,
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                _react2['default'].createElement(
                    'a',
                    {
                        href: "#top",
                        onClick: this.handleClick,
                        title: this.props.title },
                    this.props.title ? _react2['default'].createElement(
                        'span',
                        { className: this.prefixClass('title') },
                        this.props.title
                    ) : null,
                    this.renderIcon()
                )
            );
        }
    }]);

    return GoTop;
})(_react2['default'].Component);

GoTop.displayName = "GoTop";

GoTop.propTypes = {
    classPrefix: _react2['default'].PropTypes.string.isRequired,
    theme: _react2['default'].PropTypes.oneOf(['default', 'fixed']),
    title: _react2['default'].PropTypes.string,
    src: _react2['default'].PropTypes.string,
    icon: _react2['default'].PropTypes.string,
    autoHide: _react2['default'].PropTypes.bool
};

GoTop.defaultProps = {
    classPrefix: 'gotop',
    theme: 'default'
};

module.exports = GoTop;

==> totoui-0.5.1.tgz: package/lib/goTop.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var _mixinsSmoothScrollMixin = require('./mixins/SmoothScrollMixin');

var _mixinsSmoothScrollMixin2 = _interopRequireDefault(_mixinsSmoothScrollMixin);

var _utilsEvents = require('./utils/Events');

var _utilsEvents2 = _interopRequireDefault(_utilsEvents);

var _utilsDebounce = require('./utils/debounce');

var _utilsDebounce2 = _interopRequireDefault(_utilsDebounce);

var _utilsDomUtils = require('./utils/domUtils');

var _utilsDomUtils2 = _interopRequireDefault(_utilsDomUtils);

var _utilsCSSCore = require('./utils/CSSCore');

var _utilsCSSCore2 = _interopRequireDefault(_utilsCSSCore);

var _iconJsx = require('./icon.js');

var _iconJsx2 = _interopRequireDefault(_iconJsx);

var GoTop = (function (_React$Component) {
    _inherits(GoTop, _React$Component);

    function GoTop(props) {
        _classCallCheck(this, GoTop);

        _get(Object.getPrototypeOf(GoTop.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
        for (var b in _mixinsSmoothScrollMixin2['default']) {
            this[b] = _mixinsSmoothScrollMixin2['default'][b].bind(this);
        }
        this.componentDidMount = this.componentDidMount.bind(this);
        this.componentWillUnmount = this.componentWillUnmount.bind(this);
        this.checkPosition = this.checkPosition.bind(this);
        this.isAutoHide = this.isAutoHide.bind(this);
        this.renderIcon = this.renderIcon.bind(this);
        this.handleClick = this.handleClick.bind(this);
    }

    _createClass(GoTop, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            if (this.isAutoHide()) {
                var check = this.checkPosition;

                check();

                this._listener = _utilsEvents2['default'].on(window, 'scroll', (0, _utilsDebounce2['default'])(check, 100));
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this._listener && this._listener.off();
        }
    }, {
        key: 'checkPosition',
        value: function checkPosition() {
            var action = (_utilsDomUtils2['default'].scrollTop(window) > 50 ? 'add' : 'remove') + 'Class';

            _utilsCSSCore2['default'][action](_reactDom2['default'].findDOMNode(this), this.setClassNamespace('active'));
        }
    }, {
        key: 'isAutoHide',
        value: function isAutoHide() {
            return this.props.theme === 'fixed' && this.props.autoHide;
        }
    }, {
        key: 'handleClick',
        value: function handleClick(e) {
            e.preventDefault();
            this.smoothScroll();
        }
    }, {
        key: 'renderIcon',
        value: function renderIcon() {
            return this.props.src ? _react2['default'].createElement('img', {
                className: this.prefixClass('icon-custom'),
                src: this.props.src,
                alt: this.props.title }) : _react2['default'].createElement(_iconJsx2['default'], {
                className: this.prefixClass('icon'),
                icon: this.props.icon || 'chevron-up' });
        }
    }, {
        key: 'render',
        value: function render() {
            var classSet = this.getClassSet();

            classSet[this.prefixClass(this.props.theme)] = true;
            classSet[this.setClassNamespace('active')] = !this.isAutoHide();

            return _react2['default'].createElement(
                'div',
                _extends({}, this.props, {
                    'data-widget': this.props.classPrefix,
                    className: (0, _classnames2['default'])(classSet, this.props.className) }),
                _react2['default'].createElement(
                    'a',
                    {
                        href: '#top',
                        onClick: this.handleClick,
                        title: this.props.title },
                    this.props.title ? _react2['default'].createElement(
                        'span',
                        { className: this.prefixClass('title') },
                        this.props.title
                    ) : null,
                    this.renderIcon()
                )
            );
        }
    }]);

    return GoTop;
})(_react2['default'].Component);

GoTop.displayName = "GoTop";

GoTop.propTypes = {
    classPrefix: _react2['default'].PropTypes.string.isRequired,
    theme: _react2['default'].PropTypes.oneOf(['default', 'fixed']),
    title: _react2['default'].PropTypes.string,
    src: _react2['default'].PropTypes.string,
    icon: _react2['default'].PropTypes.string,
    autoHide: _react2['default'].PropTypes.bool
};

GoTop.defaultProps = {
    classPrefix: 'gotop',
    theme: 'default'
};

module.exports = GoTop;
